==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/SodaEvaluation.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
namespace com.db4o.test {

   public class SodaEvaluation {
      
      public SodaEvaluation() : base() {
      }
      internal SodaEvaluation child;
      internal String name;
      
      public void store() {
         Tester.deleteAllInstances(this);
         name = "one";
         Tester.store(this);
         SodaEvaluation se1 = new SodaEvaluation();
         se1.child = new SodaEvaluation();
         se1.child.name = "three";
         se1.name = "two";
         Tester.store(se1);
      }
      
      public void test() {
         String nameConstraint1 = "three";
         Query q1 = Tester.query();
         Query cq1 = q1;
         q1.constrain(j4o.lang.Class.getClassForObject(this));
         cq1 = cq1.descend("child");
         cq1.constrain(new MyEvaluation());
         ObjectSet os = q1.execute();
         Tester.ensure(os.size() == 1);
         SodaEvaluation se = (SodaEvaluation)os.next();
         Tester.ensure(se.name.Equals("two"));
      }
   }

	class MyEvaluation : Evaluation{
		String nameConstraint1 = "three";

            public void evaluate(Candidate candidate) 
			{
               candidate.include(((SodaEvaluation)candidate.getObject()).name.Equals(nameConstraint1));
            }
	}


}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/SodaEvaluation.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
using com.db4o.query;
namespace com.db4o.test {

   public class SodaEvaluation {
      
      public SodaEvaluation() : base() {
      }
      internal SodaEvaluation child;
      internal String name;
      
      public void Store() {
         Tester.DeleteAllInstances(this);
         name = "one";
         Tester.Store(this);
         SodaEvaluation se1 = new SodaEvaluation();
         se1.child = new SodaEvaluation();
         se1.child.name = "three";
         se1.name = "two";
         Tester.Store(se1);
      }
      
      public void Test() {
         String nameConstraint1 = "three";
         Query q1 = Tester.Query();
         Query cq1 = q1;
         q1.Constrain(j4o.lang.Class.GetClassForObject(this));
         cq1 = cq1.Descend("child");
         cq1.Constrain(new MyEvaluation());
         ObjectSet os = q1.Execute();
         Tester.Ensure(os.Size() == 1);
         SodaEvaluation se = (SodaEvaluation)os.Next();
         Tester.Ensure(se.name.Equals("two"));
      }
   }

	class MyEvaluation : Evaluation{
		String nameConstraint1 = "three";

            public void Evaluate(Candidate candidate) 
			{
               candidate.Include(((SodaEvaluation)candidate.GetObject()).name.Equals(nameConstraint1));
            }
	}


}
